core/device: Make it more clear random addresses can only be used with LE

Any random address type can only be connected over LE as BR/EDR only
support public addresses.
diff --git a/src/device.c b/src/device.c
index b8556f1..9586022 100644
--- a/src/device.c
+++ b/src/device.c
@@ -1748,8 +1748,8 @@
 	else if (!dev->bredr_state.bonded && dev->le_state.bonded)
 		return dev->bdaddr_type;
 
-	/* If the address is private it can only be connected over LE */
-	if (device_address_is_private(dev))
+	/* If the address is random it can only be connected over LE */
+	if (dev->bdaddr_type == BDADDR_LE_RANDOM)
 		return dev->bdaddr_type;
 
 	if (dev->bredr_seen) {